@@ -4,7 +4,7 @@ from qtpy import QtWidgets, QtCore, QtGui
 
 from .menu import RibbonMenu
 from .tabbar import RibbonTabBar
-from .utils import data_file_path
+from .utils import DataFile
 
 
 class RibbonApplicationButton(QtWidgets.QToolButton):
@@ -23,11 +23,13 @@ class RibbonApplicationButton(QtWidgets.QToolButton):
 
 class RibbonTitleLabel(QtWidgets.QLabel):
     """Title label in the ribbon bar."""
+
     pass
 
 
 class RibbonTitleWidget(QtWidgets.QFrame):
     """The title widget of the ribbon."""
+
     #: Signal, the help button was clicked.
     helpButtonClicked = QtCore.Signal(bool)
     #: Signal, the collapse button wa clicked.
@@ -41,7 +43,7 @@ class RibbonTitleWidget(QtWidgets.QFrame):
     _rightButtonHeight = 24
 
     @typing.overload
-    def __init__(self, title='PyQtRibbon', parent=None):
+    def __init__(self, title="PyQtRibbon", parent=None):
         pass
 
     @typing.overload
@@ -54,30 +56,22 @@ class RibbonTitleWidget(QtWidgets.QFrame):
         :param title: The title of the ribbon.
         :param parent: The parent widget.
         """
-        if (args and not isinstance(args[0], QtWidgets.QWidget)) or ('title' in kwargs):
-            title = args[0] if len(args) > 0 else kwargs.get('title', 'PyQtRibbon')
-            parent = args[1] if len(args) > 1 else kwargs.get('parent', None)
+        if (args and not isinstance(args[0], QtWidgets.QWidget)) or ("title" in kwargs):
+            title = args[0] if len(args) > 0 else kwargs.get("title", "PyQtRibbon")
+            parent = args[1] if len(args) > 1 else kwargs.get("parent", None)
         else:
-            title = 'PyQtRibbon'
-            parent = args[0] if len(args) > 0 else kwargs.get('parent', None)
+            title = "PyQtRibbon"
+            parent = args[0] if len(args) > 0 else kwargs.get("parent", None)
         super().__init__(parent)
         # Tab bar layout
         self.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
-        self._mainLayout = QtWidgets.QVBoxLayout(self)
-        self._mainLayout.setContentsMargins(0, 0, 0, 0)
-        self._mainLayout.setSpacing(0)
-        self._titleLayout = QtWidgets.QHBoxLayout()
-        self._titleLayout.setContentsMargins(0, 0, 0, 0)
-        self._titleLayout.setSpacing(0)
-        self._tabBarLayout = QtWidgets.QHBoxLayout()
+        self._tabBarLayout = QtWidgets.QHBoxLayout(self)
         self._tabBarLayout.setContentsMargins(0, 0, 0, 0)
         self._tabBarLayout.setSpacing(0)
-        self._mainLayout.addLayout(self._titleLayout)
-        self._mainLayout.addLayout(self._tabBarLayout)
 
         # Application
         self._applicationButton = RibbonApplicationButton()
-        self._applicationButton.setIcon(QtGui.QIcon(data_file_path('icons/python.png')))
+        self._applicationButton.setIcon(QtGui.QIcon(DataFile("icons/python.png")))
         self._applicationButton.setIconSize(QtCore.QSize(self._quickAccessButtonHeight, self._quickAccessButtonHeight))
         self._applicationButton.setText("PyQtRibbon")
         self._applicationButton.setToolTip("PyQtRibbon")
@@ -99,16 +93,16 @@ class RibbonTitleWidget(QtWidgets.QFrame):
         self._rightToolBar.setIconSize(QtCore.QSize(self._rightButtonHeight, self._rightButtonHeight))
         self._collapseRibbonButton = QtWidgets.QToolButton(self)
         self._collapseRibbonButton.setIconSize(QtCore.QSize(self._rightButtonHeight, self._rightButtonHeight))
-        self._collapseRibbonButton.setIcon(QtGui.QIcon(data_file_path('icons/up.png')))
+        self._collapseRibbonButton.setIcon(QtGui.QIcon(DataFile("icons/up.png")))
         self._collapseRibbonButton.setAutoRaise(True)
         self._collapseRibbonButton.setToolTip("Collapse Ribbon")
-        self._collapseRibbonButton.clicked.connect(self.collapseRibbonButtonClicked)
+        self._collapseRibbonButton.clicked.connect(self.collapseRibbonButtonClicked)  # type: ignore
         self._helpButton = QtWidgets.QToolButton(self)
         self._helpButton.setIconSize(QtCore.QSize(self._rightButtonHeight, self._rightButtonHeight))
-        self._helpButton.setIcon(QtGui.QIcon(data_file_path("icons/help.png")))
+        self._helpButton.setIcon(QtGui.QIcon(DataFile("icons/help.png")))
         self._helpButton.setAutoRaise(True)
         self._helpButton.setToolTip("Help")
-        self._helpButton.clicked.connect(self.helpButtonClicked)
+        self._helpButton.clicked.connect(self.helpButtonClicked)  # type: ignore
         self.addRightToolButton(self._collapseRibbonButton)
         self.addRightToolButton(self._helpButton)
 
@@ -121,21 +115,20 @@ class RibbonTitleWidget(QtWidgets.QFrame):
         self._tabBar.setFont(font)
         self._tabBar.setShape(QtWidgets.QTabBar.RoundedNorth)
         self._tabBar.setDocumentMode(True)
-        self._tabBar.addTab("File")
 
         # Title label
         self._titleLabel = RibbonTitleLabel(self)
         self._titleLabel.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
-        self._titleLabel.setAlignment(QtCore.Qt.AlignCenter | QtCore.Qt.AlignBottom)
+        self._titleLabel.setAlignment(QtCore.Qt.AlignCenter | QtCore.Qt.AlignBottom)  # type: ignore
         self._titleLabel.setText(title)
         font = self._titleLabel.font()
         font.setPointSize(font.pointSize() + 3)
         self._titleLabel.setFont(font)
 
-        self._titleLayout.addWidget(self._quickAccessToolBarWidget, 0)
-        self._titleLayout.addWidget(self._titleLabel, 1)
-        self._tabBarLayout.addWidget(self._tabBar, 1)
-        self._tabBarLayout.addWidget(self._rightToolBar, 0)
+        self._tabBarLayout.addWidget(self._quickAccessToolBarWidget, 0, QtCore.Qt.AlignVCenter)
+        self._tabBarLayout.addWidget(self._tabBar, 0, QtCore.Qt.AlignVCenter)
+        self._tabBarLayout.addWidget(self._titleLabel, 1, QtCore.Qt.AlignVCenter)
+        self._tabBarLayout.addWidget(self._rightToolBar, 0, QtCore.Qt.AlignVCenter)
 
     def applicationButton(self) -> RibbonApplicationButton:
         """Return the application button."""
@@ -153,7 +146,7 @@ class RibbonTitleWidget(QtWidgets.QFrame):
 
         :param widget: The widget to add.
         """
-        self._titleLayout.addWidget(widget)
+        self._tabBarLayout.addWidget(widget)
 
     def insertTitleWidget(self, index: int, widget: QtWidgets.QWidget):
         """Insert a widget to the title layout.
@@ -161,14 +154,14 @@ class RibbonTitleWidget(QtWidgets.QFrame):
         :param index: The index to insert the widget.
         :param widget: The widget to insert.
         """
-        self._titleLayout.insertWidget(index, widget)
+        self._tabBarLayout.insertWidget(index, widget)
 
     def removeTitleWidget(self, widget: QtWidgets.QWidget):
         """Remove a widget from the title layout.
 
         :param widget: The widget to remove.
         """
-        self._titleLayout.removeWidget(widget)
+        self._tabBarLayout.removeWidget(widget)
 
     def tabBar(self) -> RibbonTabBar:
         """Return the tab bar of the ribbon.
@@ -248,7 +241,7 @@ class RibbonTitleWidget(QtWidgets.QFrame):
         self._rightButtonHeight = height
         for button in self._rightToolButtons:
             button.setIconSize(QtCore.QSize(height, height))
-            
+
     def helpRibbonButton(self) -> QtWidgets.QToolButton:
         """Return the help ribbon button.
 
@@ -284,4 +277,3 @@ class RibbonTitleWidget(QtWidgets.QFrame):
         :return: The collapse ribbon button.
         """
         return self._collapseRibbonButton
-    
\ No newline at end of file
